# SPDX-FileCopyrightText: 2018 Brent Rubell for Adafruit Industries
#
# SPDX-License-Identifier: MIT

"""
`ttn_eu`
======================================================
The Things Network Frequency Plans - EU863
* Author(s): Brent Rubell
"""
TTN_FREQS = {
    0: (0xD9, 0x06, 0x8B),  # 868.1 MHz
    1: (0xD9, 0x13, 0x58),  # 868.3 MHz
    2: (0xD9, 0x20, 0x24),  # 868.5 MHz
    3: (0xD8, 0xC6, 0x8B),  # 867.1 MHz
    4: (0xD8, 0xD3, 0x58),  # 867.3 MHz
    5: (0xD8, 0xE0, 0x24),  # 867.5 MHz
    6: (0xD8, 0xEC, 0xF1),  # 867.7 MHz
    7: (0xD8, 0xF9, 0xBE),
}  # 867.9 MHz
